Module indexed

Module indexed 

Provides the Indexed wrapper type which modifies a Slicer to produce the current index as well as the value.

Structs

Indexed
A Slicer which wrapps another Slicer and modifies it to produce the index of the item as well as the item itself.