Module layerers

Provides layerer types which are used in combination with Slicer types to determine the order and form in which data is produced from the layers within a CellMap.

Structs

Many
Produces data from many layers in a CellMap
Map
Produces data from two layers in pairs of (&from, &mut to), allowing you to map data from one layer into another.
Single
Produces data from a single layer in a CellMap.

Traits

Layerer
Layerer controls how items are iterated over a CellMaps layers.